/* automatically generated from pulseaudio-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (pulseaudio_dialog_ui)
#endif
#ifdef __GNUC__
static const char pulseaudio_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char pulseaudio_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.11\"/"
  "><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">xfce4-pulseaudio-plugin</property></object><object clas"
  "s=\"GtkImage\" id=\"image2\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"icon_name"
  "\">edit-clear</property></object><object class=\"GtkListStore\" id=\"li"
  "ststore1\"><columns><column type=\"GdkPixbuf\"/><column type=\"gchararr"
  "ay\"/><column type=\"gchararray\"/><column type=\"gboolean\"/></columns"
  "></object><object class=\"XfceTitledDialog\" id=\"dialog\"><property na"
  "me=\"can_focus\">False</property><property name=\"title\" translatable="
  "\"yes\">PulseAudio Panel Plugin</property><property name=\"default_widt"
  "h\">425</property><property name=\"default_height\">525</property><prop"
  "erty name=\"icon_name\">gtk-properties</property><property name=\"type_"
  "hint\">normal</property><child internal-child=\"vbox\"><object class=\""
  "GtkBox\" id=\"dialog-vbox2\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"orientati"
  "on\">vertical</property><property name=\"spacing\">2</property><child i"
  "nternal-child=\"action_area\"><object class=\"GtkButtonBox\" id=\"dialo"
  "g-action_area2\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"layout_style\">end</p"
  "roperty><child><object class=\"GtkButton\" id=\"close-button\"><propert"
  "y name=\"label\">gtk-close</property><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">True</property><property name=\"re"
  "ceives_default\">True</property><property name=\"use_stock\">True</prop"
  "erty></object><packing><property name=\"expand\">False</property><prope"
  "rty name=\"fill\">False</property><property name=\"position\">0</proper"
  "ty></packing></child><child><object class=\"GtkButton\" id=\"help-butto"
  "n\"><property name=\"label\">gtk-help</property><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">True</property><propert"
  "y name=\"receives_default\">True</property><property name=\"use_stock\""
  ">True</property></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">False</property><property name=\"position\""
  ">1</property><property name=\"secondary\">True</property></packing></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"pack_type\">end</prope"
  "rty><property name=\"position\">0</property></packing></child><child><o"
  "bject class=\"GtkNotebook\" id=\"sections\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">True</property><property na"
  "me=\"border_width\">6</property><child><object class=\"GtkBox\" id=\"se"
  "ction_general_content\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"border_width\""
  ">12</property><property name=\"orientation\">vertical</property><proper"
  "ty name=\"spacing\">18</property><child><object class=\"GtkFrame\" id=\""
  "frame1\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label_xalign\">0</property><p"
  "roperty name=\"shadow_type\">none</property><child><object class=\"GtkA"
  "lignment\" id=\"alignment1\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"top_paddi"
  "ng\">6</property><property name=\"left_padding\">12</property><child><o"
  "bject class=\"GtkBox\" id=\"vbox2\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"or"
  "ientation\">vertical</property><property name=\"spacing\">6</property><"
  "child><object class=\"GtkCheckButton\" id=\"checkbutton-keyboard-shortc"
  "uts\"><property name=\"label\" translatable=\"yes\">Enable keyboard _sh"
  "ortcuts for volume control</property><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">True</property><property name=\"re"
  "ceives_default\">False</property><property name=\"tooltip_text\" transl"
  "atable=\"yes\">Enables volume control using multimedia keys. Make sure "
  "no other application that listens to these keys (e.g. xfce4-volumed) is"
  " running in the background.</property><property name=\"halign\">start</"
  "property><property name=\"use_underline\">True</property><property name"
  "=\"draw_indicator\">True</property></object><packing><property name=\"e"
  "xpand\">True</property><property name=\"fill\">True</property><property"
  " name=\"position\">0</property></packing></child><child><object class=\""
  "GtkCheckButton\" id=\"checkbutton-show-notifications\"><property name=\""
  "label\" translatable=\"yes\">Show _notifications when volume changes</p"
  "roperty><property name=\"visible\">True</property><property name=\"can_"
  "focus\">True</property><property name=\"receives_default\">False</prope"
  "rty><property name=\"tooltip_text\" translatable=\"yes\">Enables on-scr"
  "een volume notifications.</property><property name=\"halign\">start</pr"
  "operty><property name=\"use_underline\">True</property><property name=\""
  "draw_indicator\">True</property></object><packing><property name=\"expa"
  "nd\">True</property><property name=\"fill\">True</property><property na"
  "me=\"position\">1</property></packing></child></object></child></object"
  "></child><child type=\"label\"><object class=\"GtkLabel\" id=\"label1\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"label\" translatable=\"yes\">Behaviou"
  "r</property><attributes><attribute name=\"weight\" value=\"bold\"/></at"
  "tributes></object></child></object><packing><property name=\"expand\">F"
  "alse</property><property name=\"fill\">True</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkFram"
  "e\" id=\"frame2\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"label_xalign\">0</pr"
  "operty><property name=\"shadow_type\">none</property><child><object cla"
  "ss=\"GtkAlignment\" id=\"alignment2\"><property name=\"visible\">True</"
  "property><property name=\"can_focus\">False</property><property name=\""
  "top_padding\">6</property><property name=\"left_padding\">12</property>"
  "<child><object class=\"GtkGrid\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"row_s"
  "pacing\">6</property><property name=\"column_spacing\">12</property><ch"
  "ild><object class=\"GtkLabel\" id=\"label2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"label\" translatable=\"yes\">Audio _Mixer</property><property na"
  "me=\"use_underline\">True</property></object><packing><property name=\""
  "left_attach\">0</property><property name=\"top_attach\">0</property></p"
  "acking></child><child><object class=\"GtkEntry\" id=\"entry-mixer-comma"
  "nd\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">True</property><property name=\"tooltip_text\" translatable=\"yes\""
  ">Audio mixer command that can be executed from the context menu, e.g. \""
  "pavucontrol\", \"unity-control-center sound\".</property><property name"
  "=\"hexpand\">True</property><property name=\"invisible_char\">\342\200\242"
  "</property><property name=\"primary_icon_activatable\">False</property>"
  "<property name=\"secondary_icon_activatable\">False</property></object>"
  "<packing><property name=\"left_attach\">1</property><property name=\"to"
  "p_attach\">0</property></packing></child><child><object class=\"GtkButt"
  "on\" id=\"button-run-mixer\"><property name=\"label\" translatable=\"ye"
  "s\">_Run Audio Mixer...</property><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">True</property><property name=\"recei"
  "ves_default\">True</property><property name=\"halign\">start</property>"
  "<property name=\"image\">image1</property><property name=\"use_underlin"
  "e\">True</property></object><packing><property name=\"left_attach\">0</"
  "property><property name=\"top_attach\">1</property><property name=\"wid"
  "th\">2</property></packing></child></object></child></object></child><c"
  "hild type=\"label\"><object class=\"GtkLabel\" id=\"label3\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"label\" translatable=\"yes\">Sound Settings</pro"
  "perty><attributes><attribute name=\"weight\" value=\"bold\"/></attribut"
  "es></object></child></object><packing><property name=\"expand\">False</"
  "property><property name=\"fill\">True</property><property name=\"positi"
  "on\">1</property></packing></child></object></child><child type=\"tab\""
  "><object class=\"GtkLabel\" id=\"section_general\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"label\" translatable=\"yes\">General</property></object><p"
  "acking><property name=\"tab_fill\">False</property></packing></child><c"
  "hild><object class=\"GtkBox\" id=\"section_mp_content\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"margin_left\">10</property><property name=\"margin_ri"
  "ght\">10</property><property name=\"margin_top\">7</property><property "
  "name=\"margin_bottom\">12</property><property name=\"orientation\">vert"
  "ical</property><property name=\"spacing\">18</property><child><object c"
  "lass=\"GtkBox\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"margin_left\">2</prope"
  "rty><property name=\"margin_right\">2</property><property name=\"orient"
  "ation\">vertical</property><child><object class=\"GtkBox\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"spacing\">12</property><child><object class=\"GtkL"
  "abel\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"label\" translatable=\"yes\">Co"
  "ntrol Playback of Media Players</property><attributes><attribute name=\""
  "weight\" value=\"bold\"/></attributes></object><packing><property name="
  "\"expand\">False</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">0</property></packing></child><child><object cla"
  "ss=\"GtkSwitch\" id=\"switch-mpris-support\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property></object><p"
  "acking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"pack_type\">end</property><property na"
  "me=\"position\">1</property></packing></child></object><packing><proper"
  "ty name=\"expand\">False</property><property name=\"fill\">True</proper"
  "ty><property name=\"position\">0</property></packing></child><child><ob"
  "ject class=\"GtkAlignment\" id=\"section_mp_content_1\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"left_padding\">12</property><child><object class=\"Gt"
  "kBox\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"orientation\">vertical</propert"
  "y><property name=\"spacing\">6</property><child><object class=\"GtkChec"
  "kButton\" id=\"checkbutton-multimedia-keys\"><property name=\"label\" t"
  "ranslatable=\"yes\">Enable multimedia keys for playback control</proper"
  "ty><property name=\"visible\">True</property><property name=\"can_focus"
  "\">True</property><property name=\"receives_default\">False</property><"
  "property name=\"halign\">start</property><property name=\"draw_indicato"
  "r\">True</property></object><packing><property name=\"expand\">False</p"
  "roperty><property name=\"fill\">True</property><property name=\"positio"
  "n\">0</property></packing></child><child><object class=\"GtkCheckButton"
  "\" id=\"checkbutton-wnck\"><property name=\"label\" translatable=\"yes\""
  ">Enable experimental window focus support</property><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">True</property><pro"
  "perty name=\"receives_default\">False</property><property name=\"halign"
  "\">start</property><property name=\"draw_indicator\">True</property></o"
  "bject><packing><property name=\"expand\">False</property><property name"
  "=\"fill\">True</property><property name=\"position\">1</property></pack"
  "ing></child></object></child></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">1</property></packing></child></object><packing><property "
  "name=\"expand\">False</property><property name=\"fill\">True</property>"
  "<property name=\"position\">0</property></packing></child><child><objec"
  "t class=\"GtkFrame\" id=\"section_mp_content_2\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"margin_left\">2</property><property name=\"margin_right\">2<"
  "/property><property name=\"margin_bottom\">12</property><property name="
  "\"label_xalign\">0</property><property name=\"shadow_type\">none</prope"
  "rty><child><object class=\"GtkAlignment\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"top_padding\">6</property><property name=\"left_padding\">12</prope"
  "rty><child><object class=\"GtkBox\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"or"
  "ientation\">vertical</property><property name=\"spacing\">6</property><"
  "child><object class=\"GtkScrolledWindow\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">True</property><property name"
  "=\"shadow_type\">in</property><child><object class=\"GtkTreeView\" id=\""
  "player_tree_view\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">True</property><property name=\"model\">liststore1</"
  "property><property name=\"headers_clickable\">False</property><property"
  " name=\"enable_search\">False</property><property name=\"show_expanders"
  "\">False</property><child internal-child=\"selection\"><object class=\""
  "GtkTreeSelection\"/></child><child><object class=\"GtkTreeViewColumn\" "
  "id=\"col_icon\"><child><object class=\"GtkCellRendererPixbuf\" id=\"col"
  "_icon_renderer\"/><attributes><attribute name=\"pixbuf\">0</attribute><"
  "/attributes></child></object></child><child><object class=\"GtkTreeView"
  "Column\" id=\"col_label\"><property name=\"title\" translatable=\"yes\""
  ">Title</property><property name=\"expand\">True</property><child><objec"
  "t class=\"GtkCellRendererText\" id=\"col_label_renderer\"/><attributes>"
  "<attribute name=\"text\">2</attribute></attributes></child></object></c"
  "hild><child><object class=\"GtkTreeViewColumn\" id=\"col_hidden\"><prop"
  "erty name=\"title\" translatable=\"yes\">Hidden</property><child><objec"
  "t class=\"GtkCellRendererToggle\" id=\"col_hidden_renderer\"/><attribut"
  "es><attribute name=\"active\">3</attribute></attributes></child></objec"
  "t></child></object></child></object><packing><property name=\"expand\">"
  "True</property><property name=\"fill\">True</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkButt"
  "on\" id=\"clear_players\"><property name=\"label\" translatable=\"yes\""
  ">Clear Known Items</property><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">True</property><property name=\"receives_d"
  "efault\">True</property><property name=\"halign\">start</property><prop"
  "erty name=\"image\">image2</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">False</property><prope"
  "rty name=\"position\">1</property></packing></child><child><object clas"
  "s=\"GtkRevealer\" id=\"restart_revealer\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><child><objec"
  "t class=\"GtkLabel\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"halign\">start</p"
  "roperty><property name=\"label\" translatable=\"yes\">Please restart yo"
  "ur panel for additional players to be displayed.</property><property na"
  "me=\"wrap\">True</property><property name=\"xalign\">0</property><attri"
  "butes><attribute name=\"style\" value=\"italic\"/></attributes></object"
  "></child></object><packing><property name=\"expand\">False</property><p"
  "roperty name=\"fill\">True</property><property name=\"position\">2</pro"
  "perty></packing></child></object></child></object></child><child type=\""
  "label\"><object class=\"GtkLabel\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">False</property><property name=\"lab"
  "el\" translatable=\"yes\">Known Media Players</property><attributes><at"
  "tribute name=\"weight\" value=\"bold\"/></attributes></object></child><"
  "/object><packing><property name=\"expand\">True</property><property nam"
  "e=\"fill\">True</property><property name=\"position\">1</property></pac"
  "king></child></object><packing><property name=\"position\">1</property>"
  "</packing></child><child type=\"tab\"><object class=\"GtkLabel\" id=\"s"
  "ection_mp\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"label\" translatable=\"yes"
  "\">Media Players</property></object><packing><property name=\"position\""
  ">1</property><property name=\"tab_fill\">False</property></packing></ch"
  "ild><child><placeholder/></child><child type=\"tab\"><placeholder/></ch"
  "ild></object><packing><property name=\"expand\">True</property><propert"
  "y name=\"fill\">True</property><property name=\"position\">1</property>"
  "</packing></child></object></child><action-widgets><action-widget respo"
  "nse=\"0\">close-button</action-widget><action-widget response=\"0\">hel"
  "p-button</action-widget></action-widgets></object></interface>"
};

static const unsigned pulseaudio_dialog_ui_length = 16723u;

